// 9x16-bit sine table with 2^9=512 steps
module sineTable9x16bit (CLK, sine_addr, sine_out);
   input CLK;
   wire  CLK;
   input [8:0] sine_addr;
   wire [8:0]  sine_addr;
   output [15:0] sine_out;
   reg [15:0]    sine_out;

   always @(posedge CLK) begin
      case(sine_addr)
        9'h000: sine_out = 16'h0000; // addr = 0, sine_out = 0.000000
        9'h001: sine_out = 16'h00c9; // addr = 1, sine_out = 0.012272
        9'h002: sine_out = 16'h0192; // addr = 2, sine_out = 0.024541
        9'h003: sine_out = 16'h025b; // addr = 3, sine_out = 0.036807
        9'h004: sine_out = 16'h0323; // addr = 4, sine_out = 0.049068
        9'h005: sine_out = 16'h03ec; // addr = 5, sine_out = 0.061321
        9'h006: sine_out = 16'h04b5; // addr = 6, sine_out = 0.073565
        9'h007: sine_out = 16'h057d; // addr = 7, sine_out = 0.085797
        9'h008: sine_out = 16'h0645; // addr = 8, sine_out = 0.098017
        9'h009: sine_out = 16'h070d; // addr = 9, sine_out = 0.110222
        9'h00a: sine_out = 16'h07d5; // addr = 10, sine_out = 0.122411
        9'h00b: sine_out = 16'h089c; // addr = 11, sine_out = 0.134581
        9'h00c: sine_out = 16'h0964; // addr = 12, sine_out = 0.146730
        9'h00d: sine_out = 16'h0a2a; // addr = 13, sine_out = 0.158858
        9'h00e: sine_out = 16'h0af1; // addr = 14, sine_out = 0.170962
        9'h00f: sine_out = 16'h0bb6; // addr = 15, sine_out = 0.183040
        9'h010: sine_out = 16'h0c7c; // addr = 16, sine_out = 0.195090
        9'h011: sine_out = 16'h0d41; // addr = 17, sine_out = 0.207111
        9'h012: sine_out = 16'h0e05; // addr = 18, sine_out = 0.219101
        9'h013: sine_out = 16'h0ec9; // addr = 19, sine_out = 0.231058
        9'h014: sine_out = 16'h0f8c; // addr = 20, sine_out = 0.242980
        9'h015: sine_out = 16'h104f; // addr = 21, sine_out = 0.254866
        9'h016: sine_out = 16'h1111; // addr = 22, sine_out = 0.266713
        9'h017: sine_out = 16'h11d3; // addr = 23, sine_out = 0.278520
        9'h018: sine_out = 16'h1294; // addr = 24, sine_out = 0.290285
        9'h019: sine_out = 16'h1354; // addr = 25, sine_out = 0.302006
        9'h01a: sine_out = 16'h1413; // addr = 26, sine_out = 0.313682
        9'h01b: sine_out = 16'h14d1; // addr = 27, sine_out = 0.325310
        9'h01c: sine_out = 16'h158f; // addr = 28, sine_out = 0.336890
        9'h01d: sine_out = 16'h164c; // addr = 29, sine_out = 0.348419
        9'h01e: sine_out = 16'h1708; // addr = 30, sine_out = 0.359895
        9'h01f: sine_out = 16'h17c3; // addr = 31, sine_out = 0.371317
        9'h020: sine_out = 16'h187d; // addr = 32, sine_out = 0.382683
        9'h021: sine_out = 16'h1937; // addr = 33, sine_out = 0.393992
        9'h022: sine_out = 16'h19ef; // addr = 34, sine_out = 0.405241
        9'h023: sine_out = 16'h1aa6; // addr = 35, sine_out = 0.416430
        9'h024: sine_out = 16'h1b5d; // addr = 36, sine_out = 0.427555
        9'h025: sine_out = 16'h1c12; // addr = 37, sine_out = 0.438616
        9'h026: sine_out = 16'h1cc6; // addr = 38, sine_out = 0.449611
        9'h027: sine_out = 16'h1d79; // addr = 39, sine_out = 0.460539
        9'h028: sine_out = 16'h1e2b; // addr = 40, sine_out = 0.471397
        9'h029: sine_out = 16'h1edc; // addr = 41, sine_out = 0.482184
        9'h02a: sine_out = 16'h1f8b; // addr = 42, sine_out = 0.492898
        9'h02b: sine_out = 16'h2039; // addr = 43, sine_out = 0.503538
        9'h02c: sine_out = 16'h20e7; // addr = 44, sine_out = 0.514103
        9'h02d: sine_out = 16'h2192; // addr = 45, sine_out = 0.524590
        9'h02e: sine_out = 16'h223d; // addr = 46, sine_out = 0.534998
        9'h02f: sine_out = 16'h22e6; // addr = 47, sine_out = 0.545325
        9'h030: sine_out = 16'h238e; // addr = 48, sine_out = 0.555570
        9'h031: sine_out = 16'h2434; // addr = 49, sine_out = 0.565732
        9'h032: sine_out = 16'h24da; // addr = 50, sine_out = 0.575808
        9'h033: sine_out = 16'h257d; // addr = 51, sine_out = 0.585798
        9'h034: sine_out = 16'h261f; // addr = 52, sine_out = 0.595699
        9'h035: sine_out = 16'h26c0; // addr = 53, sine_out = 0.605511
        9'h036: sine_out = 16'h275f; // addr = 54, sine_out = 0.615232
        9'h037: sine_out = 16'h27fd; // addr = 55, sine_out = 0.624860
        9'h038: sine_out = 16'h2899; // addr = 56, sine_out = 0.634393
        9'h039: sine_out = 16'h2934; // addr = 57, sine_out = 0.643832
        9'h03a: sine_out = 16'h29cd; // addr = 58, sine_out = 0.653173
        9'h03b: sine_out = 16'h2a65; // addr = 59, sine_out = 0.662416
        9'h03c: sine_out = 16'h2afa; // addr = 60, sine_out = 0.671559
        9'h03d: sine_out = 16'h2b8e; // addr = 61, sine_out = 0.680601
        9'h03e: sine_out = 16'h2c21; // addr = 62, sine_out = 0.689541
        9'h03f: sine_out = 16'h2cb2; // addr = 63, sine_out = 0.698376
        9'h040: sine_out = 16'h2d41; // addr = 64, sine_out = 0.707107
        9'h041: sine_out = 16'h2dce; // addr = 65, sine_out = 0.715731
        9'h042: sine_out = 16'h2e5a; // addr = 66, sine_out = 0.724247
        9'h043: sine_out = 16'h2ee3; // addr = 67, sine_out = 0.732654
        9'h044: sine_out = 16'h2f6b; // addr = 68, sine_out = 0.740951
        9'h045: sine_out = 16'h2ff1; // addr = 69, sine_out = 0.749136
        9'h046: sine_out = 16'h3076; // addr = 70, sine_out = 0.757209
        9'h047: sine_out = 16'h30f8; // addr = 71, sine_out = 0.765167
        9'h048: sine_out = 16'h3179; // addr = 72, sine_out = 0.773010
        9'h049: sine_out = 16'h31f7; // addr = 73, sine_out = 0.780737
        9'h04a: sine_out = 16'h3274; // addr = 74, sine_out = 0.788346
        9'h04b: sine_out = 16'h32ee; // addr = 75, sine_out = 0.795837
        9'h04c: sine_out = 16'h3367; // addr = 76, sine_out = 0.803208
        9'h04d: sine_out = 16'h33de; // addr = 77, sine_out = 0.810457
        9'h04e: sine_out = 16'h3453; // addr = 78, sine_out = 0.817585
        9'h04f: sine_out = 16'h34c6; // addr = 79, sine_out = 0.824589
        9'h050: sine_out = 16'h3536; // addr = 80, sine_out = 0.831470
        9'h051: sine_out = 16'h35a5; // addr = 81, sine_out = 0.838225
        9'h052: sine_out = 16'h3612; // addr = 82, sine_out = 0.844854
        9'h053: sine_out = 16'h367c; // addr = 83, sine_out = 0.851355
        9'h054: sine_out = 16'h36e5; // addr = 84, sine_out = 0.857729
        9'h055: sine_out = 16'h374b; // addr = 85, sine_out = 0.863973
        9'h056: sine_out = 16'h37af; // addr = 86, sine_out = 0.870087
        9'h057: sine_out = 16'h3811; // addr = 87, sine_out = 0.876070
        9'h058: sine_out = 16'h3871; // addr = 88, sine_out = 0.881921
        9'h059: sine_out = 16'h38cf; // addr = 89, sine_out = 0.887640
        9'h05a: sine_out = 16'h392a; // addr = 90, sine_out = 0.893224
        9'h05b: sine_out = 16'h3983; // addr = 91, sine_out = 0.898674
        9'h05c: sine_out = 16'h39da; // addr = 92, sine_out = 0.903989
        9'h05d: sine_out = 16'h3a2f; // addr = 93, sine_out = 0.909168
        9'h05e: sine_out = 16'h3a82; // addr = 94, sine_out = 0.914210
        9'h05f: sine_out = 16'h3ad2; // addr = 95, sine_out = 0.919114
        9'h060: sine_out = 16'h3b20; // addr = 96, sine_out = 0.923880
        9'h061: sine_out = 16'h3b6c; // addr = 97, sine_out = 0.928506
        9'h062: sine_out = 16'h3bb6; // addr = 98, sine_out = 0.932993
        9'h063: sine_out = 16'h3bfd; // addr = 99, sine_out = 0.937339
        9'h064: sine_out = 16'h3c42; // addr = 100, sine_out = 0.941544
        9'h065: sine_out = 16'h3c84; // addr = 101, sine_out = 0.945607
        9'h066: sine_out = 16'h3cc5; // addr = 102, sine_out = 0.949528
        9'h067: sine_out = 16'h3d02; // addr = 103, sine_out = 0.953306
        9'h068: sine_out = 16'h3d3e; // addr = 104, sine_out = 0.956940
        9'h069: sine_out = 16'h3d77; // addr = 105, sine_out = 0.960431
        9'h06a: sine_out = 16'h3dae; // addr = 106, sine_out = 0.963776
        9'h06b: sine_out = 16'h3de2; // addr = 107, sine_out = 0.966976
        9'h06c: sine_out = 16'h3e14; // addr = 108, sine_out = 0.970031
        9'h06d: sine_out = 16'h3e44; // addr = 109, sine_out = 0.972940
        9'h06e: sine_out = 16'h3e71; // addr = 110, sine_out = 0.975702
        9'h06f: sine_out = 16'h3e9c; // addr = 111, sine_out = 0.978317
        9'h070: sine_out = 16'h3ec5; // addr = 112, sine_out = 0.980785
        9'h071: sine_out = 16'h3eeb; // addr = 113, sine_out = 0.983105
        9'h072: sine_out = 16'h3f0e; // addr = 114, sine_out = 0.985278
        9'h073: sine_out = 16'h3f2f; // addr = 115, sine_out = 0.987301
        9'h074: sine_out = 16'h3f4e; // addr = 116, sine_out = 0.989177
        9'h075: sine_out = 16'h3f6a; // addr = 117, sine_out = 0.990903
        9'h076: sine_out = 16'h3f84; // addr = 118, sine_out = 0.992480
        9'h077: sine_out = 16'h3f9c; // addr = 119, sine_out = 0.993907
        9'h078: sine_out = 16'h3fb1; // addr = 120, sine_out = 0.995185
        9'h079: sine_out = 16'h3fc3; // addr = 121, sine_out = 0.996313
        9'h07a: sine_out = 16'h3fd3; // addr = 122, sine_out = 0.997290
        9'h07b: sine_out = 16'h3fe1; // addr = 123, sine_out = 0.998118
        9'h07c: sine_out = 16'h3fec; // addr = 124, sine_out = 0.998795
        9'h07d: sine_out = 16'h3ff4; // addr = 125, sine_out = 0.999322
        9'h07e: sine_out = 16'h3ffb; // addr = 126, sine_out = 0.999699
        9'h07f: sine_out = 16'h3ffe; // addr = 127, sine_out = 0.999925
        9'h080: sine_out = 16'h4000; // addr = 128, sine_out = 1.000000
        9'h081: sine_out = 16'h3ffe; // addr = 129, sine_out = 0.999925
        9'h082: sine_out = 16'h3ffb; // addr = 130, sine_out = 0.999699
        9'h083: sine_out = 16'h3ff4; // addr = 131, sine_out = 0.999322
        9'h084: sine_out = 16'h3fec; // addr = 132, sine_out = 0.998795
        9'h085: sine_out = 16'h3fe1; // addr = 133, sine_out = 0.998118
        9'h086: sine_out = 16'h3fd3; // addr = 134, sine_out = 0.997290
        9'h087: sine_out = 16'h3fc3; // addr = 135, sine_out = 0.996313
        9'h088: sine_out = 16'h3fb1; // addr = 136, sine_out = 0.995185
        9'h089: sine_out = 16'h3f9c; // addr = 137, sine_out = 0.993907
        9'h08a: sine_out = 16'h3f84; // addr = 138, sine_out = 0.992480
        9'h08b: sine_out = 16'h3f6a; // addr = 139, sine_out = 0.990903
        9'h08c: sine_out = 16'h3f4e; // addr = 140, sine_out = 0.989177
        9'h08d: sine_out = 16'h3f2f; // addr = 141, sine_out = 0.987301
        9'h08e: sine_out = 16'h3f0e; // addr = 142, sine_out = 0.985278
        9'h08f: sine_out = 16'h3eeb; // addr = 143, sine_out = 0.983105
        9'h090: sine_out = 16'h3ec5; // addr = 144, sine_out = 0.980785
        9'h091: sine_out = 16'h3e9c; // addr = 145, sine_out = 0.978317
        9'h092: sine_out = 16'h3e71; // addr = 146, sine_out = 0.975702
        9'h093: sine_out = 16'h3e44; // addr = 147, sine_out = 0.972940
        9'h094: sine_out = 16'h3e14; // addr = 148, sine_out = 0.970031
        9'h095: sine_out = 16'h3de2; // addr = 149, sine_out = 0.966976
        9'h096: sine_out = 16'h3dae; // addr = 150, sine_out = 0.963776
        9'h097: sine_out = 16'h3d77; // addr = 151, sine_out = 0.960431
        9'h098: sine_out = 16'h3d3e; // addr = 152, sine_out = 0.956940
        9'h099: sine_out = 16'h3d02; // addr = 153, sine_out = 0.953306
        9'h09a: sine_out = 16'h3cc5; // addr = 154, sine_out = 0.949528
        9'h09b: sine_out = 16'h3c84; // addr = 155, sine_out = 0.945607
        9'h09c: sine_out = 16'h3c42; // addr = 156, sine_out = 0.941544
        9'h09d: sine_out = 16'h3bfd; // addr = 157, sine_out = 0.937339
        9'h09e: sine_out = 16'h3bb6; // addr = 158, sine_out = 0.932993
        9'h09f: sine_out = 16'h3b6c; // addr = 159, sine_out = 0.928506
        9'h0a0: sine_out = 16'h3b20; // addr = 160, sine_out = 0.923880
        9'h0a1: sine_out = 16'h3ad2; // addr = 161, sine_out = 0.919114
        9'h0a2: sine_out = 16'h3a82; // addr = 162, sine_out = 0.914210
        9'h0a3: sine_out = 16'h3a2f; // addr = 163, sine_out = 0.909168
        9'h0a4: sine_out = 16'h39da; // addr = 164, sine_out = 0.903989
        9'h0a5: sine_out = 16'h3983; // addr = 165, sine_out = 0.898674
        9'h0a6: sine_out = 16'h392a; // addr = 166, sine_out = 0.893224
        9'h0a7: sine_out = 16'h38cf; // addr = 167, sine_out = 0.887640
        9'h0a8: sine_out = 16'h3871; // addr = 168, sine_out = 0.881921
        9'h0a9: sine_out = 16'h3811; // addr = 169, sine_out = 0.876070
        9'h0aa: sine_out = 16'h37af; // addr = 170, sine_out = 0.870087
        9'h0ab: sine_out = 16'h374b; // addr = 171, sine_out = 0.863973
        9'h0ac: sine_out = 16'h36e5; // addr = 172, sine_out = 0.857729
        9'h0ad: sine_out = 16'h367c; // addr = 173, sine_out = 0.851355
        9'h0ae: sine_out = 16'h3612; // addr = 174, sine_out = 0.844854
        9'h0af: sine_out = 16'h35a5; // addr = 175, sine_out = 0.838225
        9'h0b0: sine_out = 16'h3536; // addr = 176, sine_out = 0.831470
        9'h0b1: sine_out = 16'h34c6; // addr = 177, sine_out = 0.824589
        9'h0b2: sine_out = 16'h3453; // addr = 178, sine_out = 0.817585
        9'h0b3: sine_out = 16'h33de; // addr = 179, sine_out = 0.810457
        9'h0b4: sine_out = 16'h3367; // addr = 180, sine_out = 0.803208
        9'h0b5: sine_out = 16'h32ee; // addr = 181, sine_out = 0.795837
        9'h0b6: sine_out = 16'h3274; // addr = 182, sine_out = 0.788346
        9'h0b7: sine_out = 16'h31f7; // addr = 183, sine_out = 0.780737
        9'h0b8: sine_out = 16'h3179; // addr = 184, sine_out = 0.773010
        9'h0b9: sine_out = 16'h30f8; // addr = 185, sine_out = 0.765167
        9'h0ba: sine_out = 16'h3076; // addr = 186, sine_out = 0.757209
        9'h0bb: sine_out = 16'h2ff1; // addr = 187, sine_out = 0.749136
        9'h0bc: sine_out = 16'h2f6b; // addr = 188, sine_out = 0.740951
        9'h0bd: sine_out = 16'h2ee3; // addr = 189, sine_out = 0.732654
        9'h0be: sine_out = 16'h2e5a; // addr = 190, sine_out = 0.724247
        9'h0bf: sine_out = 16'h2dce; // addr = 191, sine_out = 0.715731
        9'h0c0: sine_out = 16'h2d41; // addr = 192, sine_out = 0.707107
        9'h0c1: sine_out = 16'h2cb2; // addr = 193, sine_out = 0.698376
        9'h0c2: sine_out = 16'h2c21; // addr = 194, sine_out = 0.689541
        9'h0c3: sine_out = 16'h2b8e; // addr = 195, sine_out = 0.680601
        9'h0c4: sine_out = 16'h2afa; // addr = 196, sine_out = 0.671559
        9'h0c5: sine_out = 16'h2a65; // addr = 197, sine_out = 0.662416
        9'h0c6: sine_out = 16'h29cd; // addr = 198, sine_out = 0.653173
        9'h0c7: sine_out = 16'h2934; // addr = 199, sine_out = 0.643832
        9'h0c8: sine_out = 16'h2899; // addr = 200, sine_out = 0.634393
        9'h0c9: sine_out = 16'h27fd; // addr = 201, sine_out = 0.624860
        9'h0ca: sine_out = 16'h275f; // addr = 202, sine_out = 0.615232
        9'h0cb: sine_out = 16'h26c0; // addr = 203, sine_out = 0.605511
        9'h0cc: sine_out = 16'h261f; // addr = 204, sine_out = 0.595699
        9'h0cd: sine_out = 16'h257d; // addr = 205, sine_out = 0.585798
        9'h0ce: sine_out = 16'h24da; // addr = 206, sine_out = 0.575808
        9'h0cf: sine_out = 16'h2434; // addr = 207, sine_out = 0.565732
        9'h0d0: sine_out = 16'h238e; // addr = 208, sine_out = 0.555570
        9'h0d1: sine_out = 16'h22e6; // addr = 209, sine_out = 0.545325
        9'h0d2: sine_out = 16'h223d; // addr = 210, sine_out = 0.534998
        9'h0d3: sine_out = 16'h2192; // addr = 211, sine_out = 0.524590
        9'h0d4: sine_out = 16'h20e7; // addr = 212, sine_out = 0.514103
        9'h0d5: sine_out = 16'h2039; // addr = 213, sine_out = 0.503538
        9'h0d6: sine_out = 16'h1f8b; // addr = 214, sine_out = 0.492898
        9'h0d7: sine_out = 16'h1edc; // addr = 215, sine_out = 0.482184
        9'h0d8: sine_out = 16'h1e2b; // addr = 216, sine_out = 0.471397
        9'h0d9: sine_out = 16'h1d79; // addr = 217, sine_out = 0.460539
        9'h0da: sine_out = 16'h1cc6; // addr = 218, sine_out = 0.449611
        9'h0db: sine_out = 16'h1c12; // addr = 219, sine_out = 0.438616
        9'h0dc: sine_out = 16'h1b5d; // addr = 220, sine_out = 0.427555
        9'h0dd: sine_out = 16'h1aa6; // addr = 221, sine_out = 0.416430
        9'h0de: sine_out = 16'h19ef; // addr = 222, sine_out = 0.405241
        9'h0df: sine_out = 16'h1937; // addr = 223, sine_out = 0.393992
        9'h0e0: sine_out = 16'h187d; // addr = 224, sine_out = 0.382683
        9'h0e1: sine_out = 16'h17c3; // addr = 225, sine_out = 0.371317
        9'h0e2: sine_out = 16'h1708; // addr = 226, sine_out = 0.359895
        9'h0e3: sine_out = 16'h164c; // addr = 227, sine_out = 0.348419
        9'h0e4: sine_out = 16'h158f; // addr = 228, sine_out = 0.336890
        9'h0e5: sine_out = 16'h14d1; // addr = 229, sine_out = 0.325310
        9'h0e6: sine_out = 16'h1413; // addr = 230, sine_out = 0.313682
        9'h0e7: sine_out = 16'h1354; // addr = 231, sine_out = 0.302006
        9'h0e8: sine_out = 16'h1294; // addr = 232, sine_out = 0.290285
        9'h0e9: sine_out = 16'h11d3; // addr = 233, sine_out = 0.278520
        9'h0ea: sine_out = 16'h1111; // addr = 234, sine_out = 0.266713
        9'h0eb: sine_out = 16'h104f; // addr = 235, sine_out = 0.254866
        9'h0ec: sine_out = 16'h0f8c; // addr = 236, sine_out = 0.242980
        9'h0ed: sine_out = 16'h0ec9; // addr = 237, sine_out = 0.231058
        9'h0ee: sine_out = 16'h0e05; // addr = 238, sine_out = 0.219101
        9'h0ef: sine_out = 16'h0d41; // addr = 239, sine_out = 0.207111
        9'h0f0: sine_out = 16'h0c7c; // addr = 240, sine_out = 0.195090
        9'h0f1: sine_out = 16'h0bb6; // addr = 241, sine_out = 0.183040
        9'h0f2: sine_out = 16'h0af1; // addr = 242, sine_out = 0.170962
        9'h0f3: sine_out = 16'h0a2a; // addr = 243, sine_out = 0.158858
        9'h0f4: sine_out = 16'h0964; // addr = 244, sine_out = 0.146730
        9'h0f5: sine_out = 16'h089c; // addr = 245, sine_out = 0.134581
        9'h0f6: sine_out = 16'h07d5; // addr = 246, sine_out = 0.122411
        9'h0f7: sine_out = 16'h070d; // addr = 247, sine_out = 0.110222
        9'h0f8: sine_out = 16'h0645; // addr = 248, sine_out = 0.098017
        9'h0f9: sine_out = 16'h057d; // addr = 249, sine_out = 0.085797
        9'h0fa: sine_out = 16'h04b5; // addr = 250, sine_out = 0.073565
        9'h0fb: sine_out = 16'h03ec; // addr = 251, sine_out = 0.061321
        9'h0fc: sine_out = 16'h0323; // addr = 252, sine_out = 0.049068
        9'h0fd: sine_out = 16'h025b; // addr = 253, sine_out = 0.036807
        9'h0fe: sine_out = 16'h0192; // addr = 254, sine_out = 0.024541
        9'h0ff: sine_out = 16'h00c9; // addr = 255, sine_out = 0.012272
        9'h100: sine_out = 16'h0000; // addr = 256, sine_out = 0.000000
        9'h101: sine_out = 16'hff37; // addr = 257, sine_out = -0.012272
        9'h102: sine_out = 16'hfe6e; // addr = 258, sine_out = -0.024541
        9'h103: sine_out = 16'hfda5; // addr = 259, sine_out = -0.036807
        9'h104: sine_out = 16'hfcdc; // addr = 260, sine_out = -0.049068
        9'h105: sine_out = 16'hfc13; // addr = 261, sine_out = -0.061321
        9'h106: sine_out = 16'hfb4a; // addr = 262, sine_out = -0.073565
        9'h107: sine_out = 16'hfa82; // addr = 263, sine_out = -0.085797
        9'h108: sine_out = 16'hf9ba; // addr = 264, sine_out = -0.098017
        9'h109: sine_out = 16'hf8f2; // addr = 265, sine_out = -0.110222
        9'h10a: sine_out = 16'hf82a; // addr = 266, sine_out = -0.122411
        9'h10b: sine_out = 16'hf763; // addr = 267, sine_out = -0.134581
        9'h10c: sine_out = 16'hf69c; // addr = 268, sine_out = -0.146730
        9'h10d: sine_out = 16'hf5d5; // addr = 269, sine_out = -0.158858
        9'h10e: sine_out = 16'hf50f; // addr = 270, sine_out = -0.170962
        9'h10f: sine_out = 16'hf449; // addr = 271, sine_out = -0.183040
        9'h110: sine_out = 16'hf383; // addr = 272, sine_out = -0.195090
        9'h111: sine_out = 16'hf2be; // addr = 273, sine_out = -0.207111
        9'h112: sine_out = 16'hf1fa; // addr = 274, sine_out = -0.219101
        9'h113: sine_out = 16'hf136; // addr = 275, sine_out = -0.231058
        9'h114: sine_out = 16'hf073; // addr = 276, sine_out = -0.242980
        9'h115: sine_out = 16'hefb0; // addr = 277, sine_out = -0.254866
        9'h116: sine_out = 16'heeee; // addr = 278, sine_out = -0.266713
        9'h117: sine_out = 16'hee2c; // addr = 279, sine_out = -0.278520
        9'h118: sine_out = 16'hed6c; // addr = 280, sine_out = -0.290285
        9'h119: sine_out = 16'hecac; // addr = 281, sine_out = -0.302006
        9'h11a: sine_out = 16'hebec; // addr = 282, sine_out = -0.313682
        9'h11b: sine_out = 16'heb2e; // addr = 283, sine_out = -0.325310
        9'h11c: sine_out = 16'hea70; // addr = 284, sine_out = -0.336890
        9'h11d: sine_out = 16'he9b3; // addr = 285, sine_out = -0.348419
        9'h11e: sine_out = 16'he8f7; // addr = 286, sine_out = -0.359895
        9'h11f: sine_out = 16'he83c; // addr = 287, sine_out = -0.371317
        9'h120: sine_out = 16'he782; // addr = 288, sine_out = -0.382683
        9'h121: sine_out = 16'he6c9; // addr = 289, sine_out = -0.393992
        9'h122: sine_out = 16'he610; // addr = 290, sine_out = -0.405241
        9'h123: sine_out = 16'he559; // addr = 291, sine_out = -0.416430
        9'h124: sine_out = 16'he4a3; // addr = 292, sine_out = -0.427555
        9'h125: sine_out = 16'he3ed; // addr = 293, sine_out = -0.438616
        9'h126: sine_out = 16'he339; // addr = 294, sine_out = -0.449611
        9'h127: sine_out = 16'he286; // addr = 295, sine_out = -0.460539
        9'h128: sine_out = 16'he1d4; // addr = 296, sine_out = -0.471397
        9'h129: sine_out = 16'he124; // addr = 297, sine_out = -0.482184
        9'h12a: sine_out = 16'he074; // addr = 298, sine_out = -0.492898
        9'h12b: sine_out = 16'hdfc6; // addr = 299, sine_out = -0.503538
        9'h12c: sine_out = 16'hdf19; // addr = 300, sine_out = -0.514103
        9'h12d: sine_out = 16'hde6d; // addr = 301, sine_out = -0.524590
        9'h12e: sine_out = 16'hddc2; // addr = 302, sine_out = -0.534998
        9'h12f: sine_out = 16'hdd19; // addr = 303, sine_out = -0.545325
        9'h130: sine_out = 16'hdc71; // addr = 304, sine_out = -0.555570
        9'h131: sine_out = 16'hdbcb; // addr = 305, sine_out = -0.565732
        9'h132: sine_out = 16'hdb26; // addr = 306, sine_out = -0.575808
        9'h133: sine_out = 16'hda82; // addr = 307, sine_out = -0.585798
        9'h134: sine_out = 16'hd9e0; // addr = 308, sine_out = -0.595699
        9'h135: sine_out = 16'hd93f; // addr = 309, sine_out = -0.605511
        9'h136: sine_out = 16'hd8a0; // addr = 310, sine_out = -0.615232
        9'h137: sine_out = 16'hd802; // addr = 311, sine_out = -0.624860
        9'h138: sine_out = 16'hd766; // addr = 312, sine_out = -0.634393
        9'h139: sine_out = 16'hd6cb; // addr = 313, sine_out = -0.643832
        9'h13a: sine_out = 16'hd632; // addr = 314, sine_out = -0.653173
        9'h13b: sine_out = 16'hd59b; // addr = 315, sine_out = -0.662416
        9'h13c: sine_out = 16'hd505; // addr = 316, sine_out = -0.671559
        9'h13d: sine_out = 16'hd471; // addr = 317, sine_out = -0.680601
        9'h13e: sine_out = 16'hd3de; // addr = 318, sine_out = -0.689541
        9'h13f: sine_out = 16'hd34e; // addr = 319, sine_out = -0.698376
        9'h140: sine_out = 16'hd2bf; // addr = 320, sine_out = -0.707107
        9'h141: sine_out = 16'hd231; // addr = 321, sine_out = -0.715731
        9'h142: sine_out = 16'hd1a6; // addr = 322, sine_out = -0.724247
        9'h143: sine_out = 16'hd11c; // addr = 323, sine_out = -0.732654
        9'h144: sine_out = 16'hd094; // addr = 324, sine_out = -0.740951
        9'h145: sine_out = 16'hd00e; // addr = 325, sine_out = -0.749136
        9'h146: sine_out = 16'hcf8a; // addr = 326, sine_out = -0.757209
        9'h147: sine_out = 16'hcf07; // addr = 327, sine_out = -0.765167
        9'h148: sine_out = 16'hce87; // addr = 328, sine_out = -0.773010
        9'h149: sine_out = 16'hce08; // addr = 329, sine_out = -0.780737
        9'h14a: sine_out = 16'hcd8b; // addr = 330, sine_out = -0.788346
        9'h14b: sine_out = 16'hcd11; // addr = 331, sine_out = -0.795837
        9'h14c: sine_out = 16'hcc98; // addr = 332, sine_out = -0.803208
        9'h14d: sine_out = 16'hcc21; // addr = 333, sine_out = -0.810457
        9'h14e: sine_out = 16'hcbac; // addr = 334, sine_out = -0.817585
        9'h14f: sine_out = 16'hcb3a; // addr = 335, sine_out = -0.824589
        9'h150: sine_out = 16'hcac9; // addr = 336, sine_out = -0.831470
        9'h151: sine_out = 16'hca5a; // addr = 337, sine_out = -0.838225
        9'h152: sine_out = 16'hc9ee; // addr = 338, sine_out = -0.844854
        9'h153: sine_out = 16'hc983; // addr = 339, sine_out = -0.851355
        9'h154: sine_out = 16'hc91b; // addr = 340, sine_out = -0.857729
        9'h155: sine_out = 16'hc8b4; // addr = 341, sine_out = -0.863973
        9'h156: sine_out = 16'hc850; // addr = 342, sine_out = -0.870087
        9'h157: sine_out = 16'hc7ee; // addr = 343, sine_out = -0.876070
        9'h158: sine_out = 16'hc78e; // addr = 344, sine_out = -0.881921
        9'h159: sine_out = 16'hc731; // addr = 345, sine_out = -0.887640
        9'h15a: sine_out = 16'hc6d5; // addr = 346, sine_out = -0.893224
        9'h15b: sine_out = 16'hc67c; // addr = 347, sine_out = -0.898674
        9'h15c: sine_out = 16'hc625; // addr = 348, sine_out = -0.903989
        9'h15d: sine_out = 16'hc5d0; // addr = 349, sine_out = -0.909168
        9'h15e: sine_out = 16'hc57d; // addr = 350, sine_out = -0.914210
        9'h15f: sine_out = 16'hc52d; // addr = 351, sine_out = -0.919114
        9'h160: sine_out = 16'hc4df; // addr = 352, sine_out = -0.923880
        9'h161: sine_out = 16'hc493; // addr = 353, sine_out = -0.928506
        9'h162: sine_out = 16'hc44a; // addr = 354, sine_out = -0.932993
        9'h163: sine_out = 16'hc402; // addr = 355, sine_out = -0.937339
        9'h164: sine_out = 16'hc3bd; // addr = 356, sine_out = -0.941544
        9'h165: sine_out = 16'hc37b; // addr = 357, sine_out = -0.945607
        9'h166: sine_out = 16'hc33b; // addr = 358, sine_out = -0.949528
        9'h167: sine_out = 16'hc2fd; // addr = 359, sine_out = -0.953306
        9'h168: sine_out = 16'hc2c1; // addr = 360, sine_out = -0.956940
        9'h169: sine_out = 16'hc288; // addr = 361, sine_out = -0.960431
        9'h16a: sine_out = 16'hc251; // addr = 362, sine_out = -0.963776
        9'h16b: sine_out = 16'hc21d; // addr = 363, sine_out = -0.966976
        9'h16c: sine_out = 16'hc1eb; // addr = 364, sine_out = -0.970031
        9'h16d: sine_out = 16'hc1bb; // addr = 365, sine_out = -0.972940
        9'h16e: sine_out = 16'hc18e; // addr = 366, sine_out = -0.975702
        9'h16f: sine_out = 16'hc163; // addr = 367, sine_out = -0.978317
        9'h170: sine_out = 16'hc13b; // addr = 368, sine_out = -0.980785
        9'h171: sine_out = 16'hc115; // addr = 369, sine_out = -0.983105
        9'h172: sine_out = 16'hc0f1; // addr = 370, sine_out = -0.985278
        9'h173: sine_out = 16'hc0d0; // addr = 371, sine_out = -0.987301
        9'h174: sine_out = 16'hc0b1; // addr = 372, sine_out = -0.989177
        9'h175: sine_out = 16'hc095; // addr = 373, sine_out = -0.990903
        9'h176: sine_out = 16'hc07b; // addr = 374, sine_out = -0.992480
        9'h177: sine_out = 16'hc064; // addr = 375, sine_out = -0.993907
        9'h178: sine_out = 16'hc04f; // addr = 376, sine_out = -0.995185
        9'h179: sine_out = 16'hc03c; // addr = 377, sine_out = -0.996313
        9'h17a: sine_out = 16'hc02c; // addr = 378, sine_out = -0.997290
        9'h17b: sine_out = 16'hc01f; // addr = 379, sine_out = -0.998118
        9'h17c: sine_out = 16'hc013; // addr = 380, sine_out = -0.998795
        9'h17d: sine_out = 16'hc00b; // addr = 381, sine_out = -0.999322
        9'h17e: sine_out = 16'hc005; // addr = 382, sine_out = -0.999699
        9'h17f: sine_out = 16'hc001; // addr = 383, sine_out = -0.999925
        9'h180: sine_out = 16'hc000; // addr = 384, sine_out = -1.000000
        9'h181: sine_out = 16'hc001; // addr = 385, sine_out = -0.999925
        9'h182: sine_out = 16'hc005; // addr = 386, sine_out = -0.999699
        9'h183: sine_out = 16'hc00b; // addr = 387, sine_out = -0.999322
        9'h184: sine_out = 16'hc013; // addr = 388, sine_out = -0.998795
        9'h185: sine_out = 16'hc01f; // addr = 389, sine_out = -0.998118
        9'h186: sine_out = 16'hc02c; // addr = 390, sine_out = -0.997290
        9'h187: sine_out = 16'hc03c; // addr = 391, sine_out = -0.996313
        9'h188: sine_out = 16'hc04f; // addr = 392, sine_out = -0.995185
        9'h189: sine_out = 16'hc064; // addr = 393, sine_out = -0.993907
        9'h18a: sine_out = 16'hc07b; // addr = 394, sine_out = -0.992480
        9'h18b: sine_out = 16'hc095; // addr = 395, sine_out = -0.990903
        9'h18c: sine_out = 16'hc0b1; // addr = 396, sine_out = -0.989177
        9'h18d: sine_out = 16'hc0d0; // addr = 397, sine_out = -0.987301
        9'h18e: sine_out = 16'hc0f1; // addr = 398, sine_out = -0.985278
        9'h18f: sine_out = 16'hc115; // addr = 399, sine_out = -0.983105
        9'h190: sine_out = 16'hc13b; // addr = 400, sine_out = -0.980785
        9'h191: sine_out = 16'hc163; // addr = 401, sine_out = -0.978317
        9'h192: sine_out = 16'hc18e; // addr = 402, sine_out = -0.975702
        9'h193: sine_out = 16'hc1bb; // addr = 403, sine_out = -0.972940
        9'h194: sine_out = 16'hc1eb; // addr = 404, sine_out = -0.970031
        9'h195: sine_out = 16'hc21d; // addr = 405, sine_out = -0.966976
        9'h196: sine_out = 16'hc251; // addr = 406, sine_out = -0.963776
        9'h197: sine_out = 16'hc288; // addr = 407, sine_out = -0.960431
        9'h198: sine_out = 16'hc2c1; // addr = 408, sine_out = -0.956940
        9'h199: sine_out = 16'hc2fd; // addr = 409, sine_out = -0.953306
        9'h19a: sine_out = 16'hc33b; // addr = 410, sine_out = -0.949528
        9'h19b: sine_out = 16'hc37b; // addr = 411, sine_out = -0.945607
        9'h19c: sine_out = 16'hc3bd; // addr = 412, sine_out = -0.941544
        9'h19d: sine_out = 16'hc402; // addr = 413, sine_out = -0.937339
        9'h19e: sine_out = 16'hc44a; // addr = 414, sine_out = -0.932993
        9'h19f: sine_out = 16'hc493; // addr = 415, sine_out = -0.928506
        9'h1a0: sine_out = 16'hc4df; // addr = 416, sine_out = -0.923880
        9'h1a1: sine_out = 16'hc52d; // addr = 417, sine_out = -0.919114
        9'h1a2: sine_out = 16'hc57d; // addr = 418, sine_out = -0.914210
        9'h1a3: sine_out = 16'hc5d0; // addr = 419, sine_out = -0.909168
        9'h1a4: sine_out = 16'hc625; // addr = 420, sine_out = -0.903989
        9'h1a5: sine_out = 16'hc67c; // addr = 421, sine_out = -0.898674
        9'h1a6: sine_out = 16'hc6d5; // addr = 422, sine_out = -0.893224
        9'h1a7: sine_out = 16'hc731; // addr = 423, sine_out = -0.887640
        9'h1a8: sine_out = 16'hc78e; // addr = 424, sine_out = -0.881921
        9'h1a9: sine_out = 16'hc7ee; // addr = 425, sine_out = -0.876070
        9'h1aa: sine_out = 16'hc850; // addr = 426, sine_out = -0.870087
        9'h1ab: sine_out = 16'hc8b4; // addr = 427, sine_out = -0.863973
        9'h1ac: sine_out = 16'hc91b; // addr = 428, sine_out = -0.857729
        9'h1ad: sine_out = 16'hc983; // addr = 429, sine_out = -0.851355
        9'h1ae: sine_out = 16'hc9ee; // addr = 430, sine_out = -0.844854
        9'h1af: sine_out = 16'hca5a; // addr = 431, sine_out = -0.838225
        9'h1b0: sine_out = 16'hcac9; // addr = 432, sine_out = -0.831470
        9'h1b1: sine_out = 16'hcb3a; // addr = 433, sine_out = -0.824589
        9'h1b2: sine_out = 16'hcbac; // addr = 434, sine_out = -0.817585
        9'h1b3: sine_out = 16'hcc21; // addr = 435, sine_out = -0.810457
        9'h1b4: sine_out = 16'hcc98; // addr = 436, sine_out = -0.803208
        9'h1b5: sine_out = 16'hcd11; // addr = 437, sine_out = -0.795837
        9'h1b6: sine_out = 16'hcd8b; // addr = 438, sine_out = -0.788346
        9'h1b7: sine_out = 16'hce08; // addr = 439, sine_out = -0.780737
        9'h1b8: sine_out = 16'hce87; // addr = 440, sine_out = -0.773010
        9'h1b9: sine_out = 16'hcf07; // addr = 441, sine_out = -0.765167
        9'h1ba: sine_out = 16'hcf8a; // addr = 442, sine_out = -0.757209
        9'h1bb: sine_out = 16'hd00e; // addr = 443, sine_out = -0.749136
        9'h1bc: sine_out = 16'hd094; // addr = 444, sine_out = -0.740951
        9'h1bd: sine_out = 16'hd11c; // addr = 445, sine_out = -0.732654
        9'h1be: sine_out = 16'hd1a6; // addr = 446, sine_out = -0.724247
        9'h1bf: sine_out = 16'hd231; // addr = 447, sine_out = -0.715731
        9'h1c0: sine_out = 16'hd2bf; // addr = 448, sine_out = -0.707107
        9'h1c1: sine_out = 16'hd34e; // addr = 449, sine_out = -0.698376
        9'h1c2: sine_out = 16'hd3de; // addr = 450, sine_out = -0.689541
        9'h1c3: sine_out = 16'hd471; // addr = 451, sine_out = -0.680601
        9'h1c4: sine_out = 16'hd505; // addr = 452, sine_out = -0.671559
        9'h1c5: sine_out = 16'hd59b; // addr = 453, sine_out = -0.662416
        9'h1c6: sine_out = 16'hd632; // addr = 454, sine_out = -0.653173
        9'h1c7: sine_out = 16'hd6cb; // addr = 455, sine_out = -0.643832
        9'h1c8: sine_out = 16'hd766; // addr = 456, sine_out = -0.634393
        9'h1c9: sine_out = 16'hd802; // addr = 457, sine_out = -0.624860
        9'h1ca: sine_out = 16'hd8a0; // addr = 458, sine_out = -0.615232
        9'h1cb: sine_out = 16'hd93f; // addr = 459, sine_out = -0.605511
        9'h1cc: sine_out = 16'hd9e0; // addr = 460, sine_out = -0.595699
        9'h1cd: sine_out = 16'hda82; // addr = 461, sine_out = -0.585798
        9'h1ce: sine_out = 16'hdb26; // addr = 462, sine_out = -0.575808
        9'h1cf: sine_out = 16'hdbcb; // addr = 463, sine_out = -0.565732
        9'h1d0: sine_out = 16'hdc71; // addr = 464, sine_out = -0.555570
        9'h1d1: sine_out = 16'hdd19; // addr = 465, sine_out = -0.545325
        9'h1d2: sine_out = 16'hddc2; // addr = 466, sine_out = -0.534998
        9'h1d3: sine_out = 16'hde6d; // addr = 467, sine_out = -0.524590
        9'h1d4: sine_out = 16'hdf19; // addr = 468, sine_out = -0.514103
        9'h1d5: sine_out = 16'hdfc6; // addr = 469, sine_out = -0.503538
        9'h1d6: sine_out = 16'he074; // addr = 470, sine_out = -0.492898
        9'h1d7: sine_out = 16'he124; // addr = 471, sine_out = -0.482184
        9'h1d8: sine_out = 16'he1d4; // addr = 472, sine_out = -0.471397
        9'h1d9: sine_out = 16'he286; // addr = 473, sine_out = -0.460539
        9'h1da: sine_out = 16'he339; // addr = 474, sine_out = -0.449611
        9'h1db: sine_out = 16'he3ed; // addr = 475, sine_out = -0.438616
        9'h1dc: sine_out = 16'he4a3; // addr = 476, sine_out = -0.427555
        9'h1dd: sine_out = 16'he559; // addr = 477, sine_out = -0.416430
        9'h1de: sine_out = 16'he610; // addr = 478, sine_out = -0.405241
        9'h1df: sine_out = 16'he6c9; // addr = 479, sine_out = -0.393992
        9'h1e0: sine_out = 16'he782; // addr = 480, sine_out = -0.382683
        9'h1e1: sine_out = 16'he83c; // addr = 481, sine_out = -0.371317
        9'h1e2: sine_out = 16'he8f7; // addr = 482, sine_out = -0.359895
        9'h1e3: sine_out = 16'he9b3; // addr = 483, sine_out = -0.348419
        9'h1e4: sine_out = 16'hea70; // addr = 484, sine_out = -0.336890
        9'h1e5: sine_out = 16'heb2e; // addr = 485, sine_out = -0.325310
        9'h1e6: sine_out = 16'hebec; // addr = 486, sine_out = -0.313682
        9'h1e7: sine_out = 16'hecac; // addr = 487, sine_out = -0.302006
        9'h1e8: sine_out = 16'hed6c; // addr = 488, sine_out = -0.290285
        9'h1e9: sine_out = 16'hee2c; // addr = 489, sine_out = -0.278520
        9'h1ea: sine_out = 16'heeee; // addr = 490, sine_out = -0.266713
        9'h1eb: sine_out = 16'hefb0; // addr = 491, sine_out = -0.254866
        9'h1ec: sine_out = 16'hf073; // addr = 492, sine_out = -0.242980
        9'h1ed: sine_out = 16'hf136; // addr = 493, sine_out = -0.231058
        9'h1ee: sine_out = 16'hf1fa; // addr = 494, sine_out = -0.219101
        9'h1ef: sine_out = 16'hf2be; // addr = 495, sine_out = -0.207111
        9'h1f0: sine_out = 16'hf383; // addr = 496, sine_out = -0.195090
        9'h1f1: sine_out = 16'hf449; // addr = 497, sine_out = -0.183040
        9'h1f2: sine_out = 16'hf50f; // addr = 498, sine_out = -0.170962
        9'h1f3: sine_out = 16'hf5d5; // addr = 499, sine_out = -0.158858
        9'h1f4: sine_out = 16'hf69c; // addr = 500, sine_out = -0.146730
        9'h1f5: sine_out = 16'hf763; // addr = 501, sine_out = -0.134581
        9'h1f6: sine_out = 16'hf82a; // addr = 502, sine_out = -0.122411
        9'h1f7: sine_out = 16'hf8f2; // addr = 503, sine_out = -0.110222
        9'h1f8: sine_out = 16'hf9ba; // addr = 504, sine_out = -0.098017
        9'h1f9: sine_out = 16'hfa82; // addr = 505, sine_out = -0.085797
        9'h1fa: sine_out = 16'hfb4a; // addr = 506, sine_out = -0.073565
        9'h1fb: sine_out = 16'hfc13; // addr = 507, sine_out = -0.061321
        9'h1fc: sine_out = 16'hfcdc; // addr = 508, sine_out = -0.049068
        9'h1fd: sine_out = 16'hfda5; // addr = 509, sine_out = -0.036807
        9'h1fe: sine_out = 16'hfe6e; // addr = 510, sine_out = -0.024541
        9'h1ff: sine_out = 16'hff37; // addr = 511, sine_out = -0.012272
      endcase // case (sin_addr)
      $display("sine_addr = %h = %d, sine_out = %h = %d", sine_addr, sine_addr, sine_out, sine_out);
   end // always @ (posedge CLK)
endmodule // sineTable9x16bit
