// Clock parameters
`define TICK      #2
`define PHASE     #5
`define CYCLE     #10

module TOP;
   reg          MRST, CLK;
   reg          init;
   wire         busy, done;
   wire [15:0]  Ax, Ay, Az, Bx, By, Bz;
   reg [15:0]   stepsize;
   reg          lock;
   
   // Create a 50% duty cycle clock
   initial begin
      CLK = 1;
      forever begin
	       `PHASE CLK = 0;
	       `PHASE CLK = 1;
      end
   end

   circle_gen circle_generator(.CLK(CLK), .reset(MRST), .init(init), .lock(1'b1),
                               .busy(busy), .done(done),
                               .Ax(Ax), .Ay(Ay), .Az(Az),
                               .Bx(Bx), .By(By), .Bz(Bz),
                               .stepsize(stepsize));
   
   // This holds reset long enough to clear all the machine state
   initial begin
      MRST = 1;
      #86 MRST = 0;
      lock <= 1'b1;
      stepsize <= 16'd1;
      init <= 1'b1;
      #200
        init <= 1'b0;
      #8000
        $finish;
   end

   always @(posedge CLK) begin
      if (MRST) begin
         $display("Being reset");
      end
      else if (busy) begin
         $display("%d, TICK. init=%b, busy=%b, done=%b, [(%h, %h, %h), (%h, %h, %h)]",
                  $time, init, busy, done, Ax, Ay, Az, Bx, By, Bz);
         //$display("num_a = %h, num_b = %h, out = %h", num_a, num_b, out);
      end
      else begin
         $display("%d, TICK. init=%b, busy=%b, done=%b", $time, init, busy, done);
         //$display("num_a = %h, num_b = %h, out = %h", num_a, num_b, out);
      end
   end // always @ (posedge CLK)

endmodule // TOP
