// Clock parameters
`define TICK      #2
`define PHASE     #5
`define CYCLE     #10

module TOP;
   reg          MRST, CLK;
   reg          init;
   wire         busy, done;
   wire [15:0]  Ax, Ay, Az, Bx, By, Bz;
   reg [15:0]   stepsize;
   reg          lock;

   reg [15:0]    edge_Ax[0:255], edge_Ay[0:255], edge_Az[0:255],
                 edge_Bx[0:255], edge_By[0:255], edge_Bz[0:255];
   reg [7:0]    edge_count;
   reg [7:0]    edge_iterator;
   
   // Create a 50% duty cycle clock
   initial begin
      CLK = 1;
      forever begin
	       `PHASE CLK = 0;
	       `PHASE CLK = 1;
      end
   end

   circle_gen circle_generator(.CLK(CLK), .reset(MRST), .init(init), .lock(1'b1),
                               .busy(busy), .done(done),
                               .Ax(Ax), .Ay(Ay), .Az(Az),
                               .Bx(Bx), .By(By), .Bz(Bz),
                               .stepsize(stepsize));
   
   // This holds reset long enough to clear all the machine state
   initial begin
      MRST = 1;
      edge_count <= 8'd0;
      edge_iterator <= 8'd0;
      #86 MRST = 0;
      lock <= 1'b1;
      stepsize <= 16'd16;
      init <= 1'b1;
      #200
        init <= 1'b0;
      #2000
        $finish;
   end

   always @(posedge CLK) begin
      if (MRST) begin
         $display("Being reset");
      end
      else if (busy) begin
         $display("%d, TICK. init=%b, busy=%b, done=%b, [(%h, %h, %h), (%h, %h, %h)] ",
                  $time, init, busy, done, Ax, Ay, Az, Bx, By, Bz);
         edge_Ax[edge_count] <= Ax;
         edge_Ay[edge_count] <= Ay;
         edge_Az[edge_count] <= Az;
         edge_Bx[edge_count] <= Bx;
         edge_By[edge_count] <= By;
         edge_Bz[edge_count] <= Bz;
         //$display("num_a = %h, num_b = %h, out = %h", num_a, num_b, out);
         edge_count <= edge_count + 8'd1;
      end
      else begin
         //$display("%d, TICK. init=%b, busy=%b, done=%b", $time, init, busy, done);
         //$display("num_a = %h, num_b = %h, out = %h", num_a, num_b, out);

         if (edge_iterator < edge_count) begin
            $display("%d, TICK. init=%b, busy=%b, done=%b, edge_iterator = %d, [(%h, %h, %h), (%04h, %h, %h)] ",
                     $time, init, busy, done,
                     edge_iterator,
                     edge_Ax[edge_iterator], edge_Ay[edge_iterator], edge_Az[edge_iterator],
                     edge_Bx[edge_iterator], edge_By[edge_iterator], edge_Bz[edge_iterator]);

            edge_iterator <= edge_iterator + 8'd1;
         end
         
      end
   end // always @ (posedge CLK)

endmodule // TOP
