// Clock parameters
`define TICK      #2
`define PHASE     #5
`define CYCLE     #10

module TOP;
   reg          MRST, CLK;
   reg [17:0]   num_a, num_b;
   reg [17:0]   result;
   wire [17:0]  out;
   
   // Create a 50% duty cycle clock
   initial begin
      CLK = 1;
      forever begin
	       `PHASE CLK = 0;
	       `PHASE CLK = 1;
      end
   end
   
   // This holds reset long enough to clear all the machine state
   initial begin
      MRST = 1;
      #86 MRST = 0;
      num_a <= 18'b0;
      num_b <= 18'b0;
      #20 num_a <= 18'h0_8000;
      num_b <= 18'h0_4000;
      #20 num_a <= 18'h0_8000;
      num_b <= 18'h0_8000;
      #20 num_a <= 18'h3_8000;
      num_b <= 18'h0_4000;
      #10 $finish;
   end

   signed_mult mult1(out, num_a, num_b);

   always @(posedge CLK) begin
      if (MRST) begin
         $display("Being reset");
      end
      else begin
         $display("num_a = %h, num_b = %h, out = %h", num_a, num_b, out);
      end
   end // always @ (posedge CLK)
endmodule

module signed_mult (out, a, b);
   output [17:0]       out;
   input signed [17:0] a;
   input signed [17:0] b;
   wire signed [17:0]  out;
   wire signed [35:0]  mult_out;
   assign              mult_out = a * b;
   assign              out = {mult_out[35], mult_out[32:16]};
endmodule
